@@ -19,13 +19,17 @@ import (
 	"github.com/turbot/steampipe/pkg/db/db_common"
 	"github.com/turbot/steampipe/pkg/error_helpers"
 	"github.com/turbot/steampipe/pkg/filepaths"
+	"github.com/turbot/steampipe/pkg/pluginmanager"
+	pb "github.com/turbot/steampipe/pkg/pluginmanager_service/grpc/proto"
+	"github.com/turbot/steampipe/pkg/statushooks"
+	"github.com/turbot/steampipe/pkg/steampipeconfig/modconfig"
 	"github.com/turbot/steampipe/pkg/utils"
-	"github.com/turbot/steampipe/pluginmanager"
+	"github.com/turbot/steampipe/sperr"
 )
 
 // StartResult is a pseudoEnum for outcomes of StartNewInstance
 type StartResult struct {
-	Error              error
+	modconfig.ErrorAndWarnings
 	Status             StartDbStatus
 	DbState            *RunningDBInstanceInfo
 	PluginManagerState *pluginmanager.PluginManagerState
@@ -41,7 +45,7 @@ func (r *StartResult) SetError(err error) *StartResult {
 type StartDbStatus int
 
 const (
-	// start from 10 to prevent confusion with int zero-value
+	// start from 1 to prevent confusion with int zero-value
 	ServiceStarted StartDbStatus = iota + 1
 	ServiceAlreadyRunning
 	ServiceFailedToStart
@@ -66,11 +70,20 @@ func (slt StartListenType) IsValid() error {
 	return fmt.Errorf("Invalid listen type. Can be one of '%v' or '%v'", ListenTypeNetwork, ListenTypeLocal)
 }
 
-func StartServices(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) (startResult *StartResult) {
+func StartServices(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) *StartResult {
 	utils.LogTime("db_local.StartServices start")
 	defer utils.LogTime("db_local.StartServices end")
 
 	res := &StartResult{}
+
+	// if we were not successful, stop services again
+	defer func() {
+		if res.Status == ServiceStarted && res.Error != nil {
+			StopServices(ctx, false, invoker)
+			res.Status = ServiceFailedToStart
+		}
+	}()
+
 	res.DbState, res.Error = GetState()
 	if res.Error != nil {
 		return res
@@ -78,25 +91,27 @@ func StartServices(ctx context.Context, port int, listen StartListenType, invoke
 
 	if res.DbState == nil {
 		res = startDB(ctx, port, listen, invoker)
-	} else {
-		rootClient, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: res.DbState.Database, Username: constants.DatabaseSuperUser})
-		if err != nil {
-			res.Error = err
-			res.Status = ServiceFailedToStart
+		if res.Error != nil {
 			return res
 		}
-		defer rootClient.Close(ctx)
-		// so db is already running - ensure it contains command schema
-		// this is to handle the upgrade edge case where a user has a service running of an earlier version of steampipe
-		// and upgrades to this version - we need to ensure we create the command schema
-		res.Error = ensureCommandSchema(ctx, rootClient)
+	} else {
 		res.Status = ServiceAlreadyRunning
 	}
 
-	if res.Error != nil {
-		return res
+	// start plugin manager if needed
+	res = ensurePluginManager(res)
+	if res.Status == ServiceStarted {
+		// execute post startup setup
+		if err := postServiceStart(ctx, res); err != nil {
+			// NOTE do not update res.Status - this will be done by defer block
+			res.Error = err
+		}
 	}
+	return res
+}
 
+func ensurePluginManager(res *StartResult) *StartResult {
+	// start the plugin manager if needed
 	res.PluginManagerState, res.Error = pluginmanager.LoadPluginManagerState()
 	if res.Error != nil {
 		res.Status = ServiceFailedToStart
@@ -104,7 +119,6 @@ func StartServices(ctx context.Context, port int, listen StartListenType, invoke
 	}
 
 	if !res.PluginManagerState.Running {
-		// start the plugin manager
 		// get the location of the currently running steampipe process
 		executable, err := os.Executable()
 		if err != nil {
@@ -115,12 +129,74 @@ func StartServices(ctx context.Context, port int, listen StartListenType, invoke
 			log.Printf("[WARN] StartServices plugin manager failed to start: %s", err)
 			return res.SetError(err)
 		}
+		// set status to service started as started plugin manager
 		res.Status = ServiceStarted
 	}
-
 	return res
 }
 
+func postServiceStart(ctx context.Context, res *StartResult) error {
+	conn, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: res.DbState.Database, Username: constants.DatabaseSuperUser})
+	if err != nil {
+		return err
+	}
+	defer conn.Close(ctx)
+
+	statushooks.SetStatus(ctx, "Dropping legacy schema")
+	if err := dropLegacyInternalSchema(ctx, conn); err != nil {
+		// do not fail
+		// worst case scenario is that we have a couple of extra schema
+		// these won't be in the search path anyway
+		log.Println("[INFO] failed to drop legacy 'internal' schema", err)
+	}
+
+	// setup internal schema
+	// this includes setting the state of all connections in the connection_state table to pending
+	statushooks.SetStatus(ctx, "Setting up functions")
+	if err := setupInternal(ctx, conn); err != nil {
+		return err
+	}
+	// ensure connection stat etable contains entries for all connections in connection config
+	// (this is to allow for the race condition between polling connection state and calling refresh connections,
+	// which does not update the connection_state with added connections until it has built the ConnectionUpdates
+	if err := initializeConnectionStateTable(ctx, conn); err != nil {
+		return err
+	}
+
+	// create the clone_foreign_schema function
+	if _, err := executeSqlAsRoot(ctx, cloneForeignSchemaSQL); err != nil {
+		return sperr.WrapWithMessage(err, "failed to create clone_foreign_schema function")
+	}
+	// create the clone_comments function
+	if _, err := executeSqlAsRoot(ctx, cloneCommentsSQL); err != nil {
+		return sperr.WrapWithMessage(err, "failed to create clone_comments function")
+	}
+
+	// if there is an unprocessed db backup file, restore it now
+	if err := restoreDBBackup(ctx); err != nil {
+		return sperr.WrapWithMessage(err, "failed to migrate db public schema")
+	}
+
+	// call initial refresh connections
+	// get plugin manager client
+	pluginManager, err := pluginmanager.GetPluginManager()
+	if err != nil {
+		return err
+	}
+
+	// ask the plugin manager to refresh connections
+	// execute async and ignore result (if there is an error we will receive a PG notification)
+	// unless STEAMPIPE_SYNC_REFRESH is set - used for acceptance testing
+	if _, synchronousRefresh := os.LookupEnv("STEAMPIPE_SYNC_REFRESH"); synchronousRefresh {
+		pluginManager.RefreshConnections(&pb.RefreshConnectionsRequest{})
+	} else {
+		go pluginManager.RefreshConnections(&pb.RefreshConnectionsRequest{})
+	}
+
+	statushooks.SetStatus(ctx, "Service startup complete")
+	return nil
+}
+
 // StartDB starts the database if not already running
 func startDB(ctx context.Context, port int, listen StartListenType, invoker constants.Invoker) (res *StartResult) {
 	log.Printf("[TRACE] StartDB invoker %s", invoker)
@@ -149,8 +225,6 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 		}
 	}()
 
-	log.Printf("[TRACE] StartDB started plugin manager")
-
 	// remove the stale info file, ignoring errors - will overwrite anyway
 	_ = removeRunningInstanceInfo()
 
@@ -221,36 +295,31 @@ func startDB(ctx context.Context, port int, listen StartListenType, invoker cons
 }
 
 func ensureService(ctx context.Context, databaseName string) error {
-	rootClient, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: databaseName, Username: constants.DatabaseSuperUser})
+	connection, err := CreateLocalDbConnection(ctx, &CreateDbOptions{DatabaseName: databaseName, Username: constants.DatabaseSuperUser})
 	if err != nil {
 		return err
 	}
-	defer rootClient.Close(ctx)
+	defer connection.Close(ctx)
 
 	// ensure the foreign server exists in the database
-	err = ensureSteampipeServer(ctx, rootClient)
+	err = ensureSteampipeServer(ctx, connection)
 	if err != nil {
 		return err
 	}
 
 	// ensure that the necessary extensions are installed in the database
-	err = ensurePgExtensions(ctx, rootClient)
+	err = ensurePgExtensions(ctx, connection)
 	if err != nil {
 		// there was a problem with the installation
 		return err
 	}
 
 	// ensure permissions for writing to temp tables
-	err = ensureTempTablePermissions(ctx, databaseName, rootClient)
+	err = ensureTempTablePermissions(ctx, databaseName, connection)
 	if err != nil {
 		return err
 	}
 
-	// ensure the db contains command schema
-	err = ensureCommandSchema(ctx, rootClient)
-	if err != nil {
-		return err
-	}
 	return nil
 }
 
@@ -432,10 +501,10 @@ func setServicePassword(ctx context.Context, password string) error {
 	}
 	defer connection.Close(ctx)
 	statements := []string{
-		"lock table pg_user;",
-		fmt.Sprintf(`alter user steampipe with password '%s';`, password),
+		"LOCK TABLE pg_user IN SHARE ROW EXCLUSIVE MODE;",
+		fmt.Sprintf(`ALTER USER steampipe WITH PASSWORD '%s';`, password),
 	}
-	_, err = executeSqlInTransaction(ctx, connection, statements...)
+	_, err = ExecuteSqlInTransaction(ctx, connection, statements...)
 	return err
 }
 
@@ -520,20 +589,6 @@ func ensureSteampipeServer(ctx context.Context, rootClient *pgx.Conn) error {
 	return nil
 }
 
-// create the command schema and grant insert permission
-func ensureCommandSchema(ctx context.Context, rootClient *pgx.Conn) error {
-	commandSchemaStatements := []string{
-		"lock table pg_namespace;",
-		getUpdateConnectionQuery(constants.CommandSchema, constants.CommandSchema),
-		fmt.Sprintf("grant insert on %s.%s to steampipe_users;", constants.CommandSchema, constants.CommandTableCache),
-		fmt.Sprintf("grant select on %s.%s to steampipe_users;", constants.CommandSchema, constants.CommandTableScanMetadata),
-	}
-	if _, err := executeSqlInTransaction(ctx, rootClient, commandSchemaStatements...); err != nil {
-		return err
-	}
-	return nil
-}
-
 // ensures that the 'steampipe_users' role has permissions to work with temporary tables
 // this is done during database installation, but we need to migrate current installations
 func ensureTempTablePermissions(ctx context.Context, databaseName string, rootClient *pgx.Conn) error {
@@ -541,7 +596,7 @@ func ensureTempTablePermissions(ctx context.Context, databaseName string, rootCl
 		"lock table pg_namespace;",
 		fmt.Sprintf("grant temporary on database %s to %s", databaseName, constants.DatabaseUser),
 	}
-	if _, err := executeSqlInTransaction(ctx, rootClient, statements...); err != nil {
+	if _, err := ExecuteSqlInTransaction(ctx, rootClient, statements...); err != nil {
 		return err
 	}
 	return nil
