@@ -44,6 +44,7 @@ func NewConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpdateCo
 	// validate the updates
 	// this will validate all plugins and connection names  and remove any updates which use invalid connections
 	updates.validate()
+
 	return updates, res
 }
 
@@ -59,7 +60,7 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpd
 	}
 	defer conn.Release()
 
-	log.Printf("[TRACE] Loading connection state")
+	log.Printf("[INFO] Loading connection state")
 	// load the connection state file and filter out any connections which are not in the list of schemas
 	// this allows for the database being rebuilt,modified externally
 	currentConnectionStateMap, err := LoadConnectionState(ctx, conn.Conn())
@@ -76,7 +77,7 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpd
 		log.Printf("[WARN] failed to build required connection state: %s", err.Error())
 		return nil, NewErrorRefreshConnectionResult(err)
 	}
-	log.Printf("[TRACE] built required connection state")
+	log.Printf("[INFO] built required connection state")
 
 	// build lookup of disabled connections
 	disabled := make(map[string]struct{})
@@ -99,7 +100,7 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpd
 	log.Printf("[INFO] loaded connection state")
 	updates.CurrentConnectionState = currentConnectionStateMap
 
-	log.Printf("[INFO] Loading dynamic schema hashes")
+	log.Printf("[INFO] loading dynamic schema hashes")
 
 	// for any connections with dynamic schema, we need to reload their schema
 	// instantiate connection plugins for all connections with dynamic schema - this will retrieve their current schema
@@ -114,22 +115,22 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpd
 	for k, v := range dynamicSchemaHashMap {
 		log.Printf("[INFO] %s: %s", k, v)
 	}
-	log.Printf("[INFO] Identify connections to update")
+	log.Printf("[INFO] identify connections to update")
 
 	modTime := time.Now()
 	// connections to create/update
 	for name, requiredConnectionState := range requiredConnectionStateMap {
 		// if the connection requires update, add to list
 		if connectionRequiresUpdate(forceUpdateConnectionNames, name, currentConnectionStateMap, requiredConnectionState) {
-			log.Printf("[TRACE] connection %s is out of date or missing", name)
 			updates.Update[name] = requiredConnectionState
+			log.Printf("[INFO] connection %s is out of date or missing. updates: %v", name, maps.Keys(updates.Update))
 
 			// set the connection mod time of required connection data to now
 			requiredConnectionState.ConnectionModTime = modTime
 		}
 	}
 
-	log.Printf("[TRACE] Identify connections to delete")
+	log.Printf("[INFO] Identify connections to delete")
 	// connections to delete - any connection which is in connection state but NOT required connections
 	for name, currentState := range currentConnectionStateMap {
 		if _, connectionRequired := requiredConnectionStateMap[name]; !connectionRequired {
@@ -186,6 +187,8 @@ func populateConnectionUpdates(ctx context.Context, pool *pgxpool.Pool, forceUpd
 	// this uses data from the ConnectionPlugins which we have now loaded
 	updates.updateRequiredStateWithSchemaProperties(dynamicSchemaHashMap)
 
+	// for all updates/deletes, if there any aggregators of the same plugin type, update those as well
+	updates.populateAggregators()
 	res.Updates = updates
 	return updates, res
 }
@@ -368,6 +371,42 @@ func (u *ConnectionUpdates) DynamicUpdates() []string {
 	return dynamicUpdates
 }
 
+func (u *ConnectionUpdates) populateAggregators() {
+	log.Printf("[INFO] populateAggregators")
+	// build map of aggregator connections keyed by plugin
+	pluginAggregatorMap := make(map[string][]string)
+
+	for connectionName, state := range u.FinalConnectionState {
+		if state.GetType() == modconfig.ConnectionTypeAggregator {
+			pluginAggregatorMap[state.Plugin] = append(pluginAggregatorMap[state.Plugin], connectionName)
+		}
+	}
+
+	log.Printf("[INFO] found %d %s with aggregators", len(pluginAggregatorMap), utils.Pluralize("plugin", len(pluginAggregatorMap)))
+
+	// for all updates/deletes, if there any aggregators of the same plugin type, update those as well
+	// build a map of all plugins with connecitons being updated/deleted
+	modifiedPluginLookup := make(map[string]struct{})
+	for _, c := range u.Update {
+		modifiedPluginLookup[c.Plugin] = struct{}{}
+	}
+	for c := range u.Delete {
+		plugin := u.CurrentConnectionState[c].Plugin
+		modifiedPluginLookup[plugin] = struct{}{}
+	}
+	for plugin := range modifiedPluginLookup {
+		aggregatorsForPlugin := pluginAggregatorMap[plugin]
+		numAggregatorsForPlugin := len(aggregatorsForPlugin)
+		if numAggregatorsForPlugin > 0 {
+			log.Printf("[INFO] plugin %s has modified connections - marking  %d %s as requiring update", plugin, numAggregatorsForPlugin, utils.Pluralize("aggregator", numAggregatorsForPlugin))
+			for _, aggregatorConnection := range aggregatorsForPlugin {
+				u.Update[aggregatorConnection] = u.FinalConnectionState[aggregatorConnection]
+			}
+		}
+	}
+
+}
+
 func getSchemaHashesForDynamicSchemas(requiredConnectionData ConnectionStateMap, connectionState ConnectionStateMap) (map[string]string, map[string]*ConnectionPlugin, error) {
 	log.Printf("[TRACE] getSchemaHashesForDynamicSchemas")
 	// for every required connection, check the connection state to determine whether the schema mode is 'dynamic'
