@@ -51,6 +51,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "aws",
 					Plugin:          "hub.steampipe.io/plugins/turbot/aws@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "access_key = \"aws_dmi_001_access_key\"\nregions    = \"- us-east-1\\n-us-west-\"\nsecret_key = \"aws_dmi_001_secret_key\"\n",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/multiple_connections/config/connection1.spc",
@@ -71,6 +72,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "aws",
 					Plugin:          "hub.steampipe.io/plugins/turbot/aws@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "access_key = \"aws_dmi_002_access_key\"\nregions    = \"- us-east-1\\n-us-west-\"\nsecret_key = \"aws_dmi_002_secret_key\"\n",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/multiple_connections/config/connection2.spc",
@@ -102,6 +104,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "test_data/connection-test-1",
 					Plugin:          "hub.steampipe.io/plugins/test_data/connection-test-1@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/single_connection/config/connection1.spc",
@@ -133,6 +136,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "test_data/connection-test-1",
 					Plugin:          "hub.steampipe.io/plugins/test_data/connection-test-1@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/single_connection_with_default_options/config/connection1.spc",
@@ -158,15 +162,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 				Listen:     &databaseListen,
 				SearchPath: &databaseSearchPath,
 			},
-			TerminalOptions: &options.Terminal{
-				Output:       &terminalOutput,
-				Separator:    &terminalSeparator,
-				Header:       &terminalHeader,
-				Multi:        &terminalMulti,
-				Timing:       &terminalTiming,
-				SearchPath:   &terminalSearchPath,
-				AutoComplete: &terminalAutoComplete,
-			},
 			GeneralOptions: &options.General{
 				UpdateCheck: &generalUpdateCheck,
 			},
@@ -187,6 +182,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "test_data/connection-test-1",
 					Plugin:          "hub.steampipe.io/plugins/test_data/connection-test-1@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/single_connection_with_default_options/config/connection1.spc",
@@ -212,16 +208,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 				Listen:     &databaseListen,
 				SearchPath: &databaseSearchPath,
 			},
-			TerminalOptions: &options.Terminal{
-				Output:           &terminalOutput,
-				Separator:        &terminalSeparator,
-				Header:           &terminalHeader,
-				Multi:            &terminalMulti,
-				Timing:           &terminalTiming,
-				SearchPath:       &terminalSearchPath,
-				SearchPathPrefix: &workspaceSearchPathPrefix,
-				AutoComplete:     &terminalAutoComplete,
-			},
 			GeneralOptions: &options.General{
 				UpdateCheck: &generalUpdateCheck,
 			},
@@ -237,6 +223,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 					PluginShortName: "test_data/connection-test-1",
 					Plugin:          "hub.steampipe.io/plugins/test_data/connection-test-1@latest",
 					Type:            "",
+					ImportSchema:    "enabled",
 					Config:          "",
 					DeclRange: modconfig.Range{
 						Filename: "$$test_pwd$$/testdata/connection_config/single_connection_with_default_options/config/connection1.spc",
@@ -262,16 +249,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 				Listen:     &databaseListen,
 				SearchPath: &databaseSearchPath,
 			},
-			TerminalOptions: &options.Terminal{
-				Output:           &workspaceOutput,
-				Separator:        &terminalSeparator,
-				Header:           &terminalHeader,
-				Multi:            &workspaceMulti,
-				Timing:           &terminalTiming,
-				SearchPath:       &workspaceSearchPath,
-				SearchPathPrefix: &workspaceSearchPathPrefix,
-				AutoComplete:     &workspaceAutoComplete,
-			},
 			GeneralOptions: &options.General{
 				UpdateCheck: &generalUpdateCheck,
 			},
@@ -283,6 +260,7 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 			Connections: map[string]*modconfig.Connection{
 				"a": {
 					Name:            "a",
+					ImportSchema:    "enabled",
 					PluginShortName: "test_data/connection-test-1",
 					Plugin:          "hub.steampipe.io/plugins/test_data/connection-test-1@latest",
 					Config:          "",
@@ -314,15 +292,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 				Listen:     &databaseListen,
 				SearchPath: &databaseSearchPath,
 			},
-			TerminalOptions: &options.Terminal{
-				Output:       &terminalOutput,
-				Separator:    &terminalSeparator,
-				Header:       &terminalHeader,
-				Multi:        &terminalMulti,
-				Timing:       &terminalTiming,
-				SearchPath:   &terminalSearchPath,
-				AutoComplete: &terminalAutoComplete,
-			},
 			GeneralOptions: &options.General{
 				UpdateCheck: &generalUpdateCheck,
 			},
@@ -341,15 +310,6 @@ var testCasesLoadConfig = map[string]loadConfigTest{
 				Listen:     &databaseListen,
 				SearchPath: &databaseSearchPath,
 			},
-			TerminalOptions: &options.Terminal{
-				Output:       &terminalOutput,
-				Separator:    &terminalSeparator,
-				Header:       &terminalHeader,
-				Multi:        &terminalMulti,
-				Timing:       &terminalTiming,
-				SearchPath:   &terminalSearchPath,
-				AutoComplete: &terminalAutoComplete,
-			},
 			GeneralOptions: &options.General{
 				UpdateCheck: &generalUpdateCheck,
 			},
@@ -388,10 +348,10 @@ func TestLoadConfig(t *testing.T) {
 		filepaths.SteampipeDir = steampipeDir
 
 		// now load config
-		config, err := loadSteampipeConfig(workspaceDir, "")
-		if err != nil {
+		config, errorsAndWarnings := loadSteampipeConfig(workspaceDir, "")
+		if errorsAndWarnings.GetError() != nil {
 			if test.expected != "ERROR" {
-				t.Errorf("Test: '%s'' FAILED with unexpected error: %v", name, err)
+				t.Errorf("Test: '%s'' FAILED with unexpected error: %v", name, errorsAndWarnings.GetError())
 			}
 			continue
 		}
